Installation
--------------

To install this package, run:
`
pip install git+https://github.com/cmudrc/drcutils.git
`

Examples
----------
You can find usage examples here:

Basic functionality: [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/cmudrc/drcutils/blob/main/examples/basic_functionality.ipynb) 

Advanced examples: [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/cmudrc/drcutils/blob/main/examples/logo_adventures.ipynb) 
